@@ -2,20 +2,19 @@
 from pathlib import Path
 
 from fbc_curation.compare import FrogComparison
-from fbc_curation.worker import frog_task
+from fbc_curation.worker import run_frog
 
 
 def create_frog(model_path: Path, omex_path: Path) -> None:
     """Create FROG report and writes OMEX for given model."""
 
-    # create FROG in OMEX
-    frog_task(
-        source_path_str=str(model_path),
-        input_is_temporary=False,
-        omex_path_str=str(omex_path),
+    # create FROG and write to COMBINE archive
+    run_frog(
+        source_path=model_path,
+        omex_path=omex_path,
     )
 
-    # compare FROG results in OMEX
+    # compare FROG results in created COMBINE archive
     model_reports = FrogComparison.read_reports_from_omex(omex_path=omex_path)
     for _, reports in model_reports.items():
         FrogComparison.compare_reports(reports=reports)
